================================================
PyFOL(Python function optimization Library)
================================================

Describe:
============================================
Optimize Python functions to give users more *convenient* and *efficient* use of various functions

NowVersion:
============================================
1.1.7.3(*New functions 'c' and 'a' in class Digit --> Combination AND Arrangement*)

Existing functions:
============================================
* String(Class)
    + setstr
    + clearstr
    + split
    + replace
    + find
    + append
    + insert
    + add
    + delete
    + pop
    + count
    + reverse
    + chartotal
    + dateformat
    
* Digit(Class)
    + plus
    + minus
    + mult
    + divide
    + mod
    + abs
    + opp
    + avg
    + square
    + cube
    + e
    + sum
    + pow(int,int)
    + fac(int)
    + sqrt
    + c
    + a
    
* DataStruct(Class):
    * LinkedList(Class)
        + isempty
        + length
        + append
        + insert
        + add
        + remove
        + delete
        + isexist
        + setvalue
        + search
        + show

    * Queue(Class):
        + isempty
        + isfull
        + length
        + put
        + leave
        + show

    * Stack(Class):
        + isempty
        + isfull
        + height
        + push
        + pop
        + show

* Data(Class):
    + swap
    + maxlst
    + minlst
    + randms

* Help(Class):
    + StringHelp(Setstr,Clearstr...)

Installation instructions:
============================================
Code support version >=3.7
(*If you can't download the latest version, please upgrade your Python to about version 3.8*)

Download method: 
============================================
pip(3) install PyFOL
Reference through import pyfol

LICENSE
============================================
See license for *copyright documents*
